==> hub_rest_client-0.1.1-py3-none-any.whl: hub_rest_client/api/default/get_users_user_id_refreshtokens_refresh_token_id.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.refresh_token import RefreshToken
from ...types import UNSET, Response, Unset


def _get_kwargs(
    user_id: str,
    refresh_token_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "id,creationTime,lastAccessTime",
) -> Dict[str, Any]:
    url = "{}/users/{userId}/refreshtokens/{refreshTokenId}".format(
        client.hub_base_url, userId=user_id, refreshTokenId=refresh_token_id
    )

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "fields": fields,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[RefreshToken]:
    if response.status_code == 200:
        response_200 = RefreshToken.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[RefreshToken]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    user_id: str,
    refresh_token_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "id,creationTime,lastAccessTime",
) -> Response[RefreshToken]:
    kwargs = _get_kwargs(
        user_id=user_id,
        refresh_token_id=refresh_token_id,
        client=client,
        fields=fields,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    user_id: str,
    refresh_token_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "id,creationTime,lastAccessTime",
) -> Optional[RefreshToken]:
    """ """

    return sync_detailed(
        user_id=user_id,
        refresh_token_id=refresh_token_id,
        client=client,
        fields=fields,
    ).parsed


async def asyncio_detailed(
    user_id: str,
    refresh_token_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "id,creationTime,lastAccessTime",
) -> Response[RefreshToken]:
    kwargs = _get_kwargs(
        user_id=user_id,
        refresh_token_id=refresh_token_id,
        client=client,
        fields=fields,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    user_id: str,
    refresh_token_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "id,creationTime,lastAccessTime",
) -> Optional[RefreshToken]:
    """ """

    return (
        await asyncio_detailed(
            user_id=user_id,
            refresh_token_id=refresh_token_id,
            client=client,
            fields=fields,
        )
    ).parsed

==> hub_rest_client-0.1.2-py3-none-any.whl: hub_rest_client/api/default/get_users_user_id_refreshtokens_refresh_token_id.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models import refresh_token as refresh_token_m
from ...types import UNSET, Response, Unset


def _get_kwargs(
    user_id: "str",
    refresh_token_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "id,creationTime,lastAccessTime",
) -> Dict[str, Any]:
    url = "{}/users/{userId}/refreshtokens/{refreshTokenId}".format(
        client.hub_base_url, userId=user_id, refreshTokenId=refresh_token_id
    )

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "fields": fields,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[refresh_token_m.RefreshToken]:
    if response.status_code == 200:
        response_200 = refresh_token_m.RefreshToken.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[refresh_token_m.RefreshToken]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    user_id: "str",
    refresh_token_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "id,creationTime,lastAccessTime",
) -> Response[refresh_token_m.RefreshToken]:
    kwargs = _get_kwargs(
        user_id=user_id,
        refresh_token_id=refresh_token_id,
        client=client,
        fields=fields,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    user_id: "str",
    refresh_token_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "id,creationTime,lastAccessTime",
) -> Optional[refresh_token_m.RefreshToken]:
    """ """

    return sync_detailed(
        user_id=user_id,
        refresh_token_id=refresh_token_id,
        client=client,
        fields=fields,
    ).parsed


async def asyncio_detailed(
    user_id: "str",
    refresh_token_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "id,creationTime,lastAccessTime",
) -> Response[refresh_token_m.RefreshToken]:
    kwargs = _get_kwargs(
        user_id=user_id,
        refresh_token_id=refresh_token_id,
        client=client,
        fields=fields,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    user_id: "str",
    refresh_token_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "id,creationTime,lastAccessTime",
) -> Optional[refresh_token_m.RefreshToken]:
    """ """

    return (
        await asyncio_detailed(
            user_id=user_id,
            refresh_token_id=refresh_token_id,
            client=client,
            fields=fields,
        )
    ).parsed
